@@ -14,6 +14,9 @@ using namespace KFileMetaData;
 Exiv2Extractor::Exiv2Extractor(QObject* parent)
     : ExtractorPlugin(parent)
 {
+#ifdef EXV_ENABLE_BMFF
+    Exiv2::enableBMFF(true);
+#endif
 }
 
 namespace
@@ -28,6 +31,12 @@ static const QStringList supportedMimeTypes = {
     QStringLiteral("image/tiff"),
 #ifdef HAVE_WEBP_SUPPORT
     QStringLiteral("image/webp"),
+#endif
+#ifdef EXV_ENABLE_BMFF
+    QStringLiteral("image/avif"),
+    QStringLiteral("image/heif"),
+    QStringLiteral("image/jxl"),
+    QStringLiteral("image/x-canon-cr3"),
 #endif
     QStringLiteral("image/x-exv"),
     QStringLiteral("image/x-canon-cr2"),
@@ -66,7 +75,11 @@ QVariant toVariantDateTime(const Exiv2::Value& value)
 QVariant toVariantLong(const Exiv2::Value& value)
 {
     if (value.typeId() == Exiv2::unsignedLong || value.typeId() == Exiv2::signedLong) {
+#if EXIV2_TEST_VERSION(0,28,0)
+        qlonglong val = value.toInt64();
+#else
         qlonglong val = value.toLong();
+#endif
         return QVariant(val);
     }
 
@@ -301,7 +314,11 @@ double Exiv2Extractor::fetchGpsAltitude(const Exiv2::ExifData& data)
         it = data.findKey(Exiv2::ExifKey("Exif.GPSInfo.GPSAltitudeRef"));
         if (it != data.end() && it->count() > 0 &&
             (it->value().typeId() == Exiv2::unsignedByte || it->value().typeId() == Exiv2::signedByte)) {
+#if EXIV2_TEST_VERSION(0,28,0)
+            auto altRef = it->value().toInt64();
+#else
             auto altRef = it->value().toLong();
+#endif
             if (altRef) {
                 alt = -1.0 * ratio.first / ratio.second;
             } else {
@@ -322,3 +339,5 @@ QByteArray Exiv2Extractor::fetchByteArray(const Exiv2::ExifData& data, const cha
 
     return QByteArray();
 }
+
+#include "moc_exiv2extractor.cpp"
